@@ -1,16 +1,15 @@
 from django.contrib.gis.db import models
 from django.contrib.postgres import fields
 from django.core.validators import MaxValueValidator, MinValueValidator
-from django.db.models import Sum
 from django_extensions.db.models import TimeStampedModel
 from rgd.models import ChecksumFile, SpatialEntry
-from rgd.models.mixins import DetailViewMixin, PermissionPathMixin, TaskEventMixin
+from rgd.models.mixins import DetailViewMixin, TaskEventMixin
 from rgd_imagery.tasks import jobs
 
 from .base import ImageSet
 
 
-class Raster(TimeStampedModel, TaskEventMixin, PermissionPathMixin):
+class Raster(TimeStampedModel, TaskEventMixin):
     """This class is a container for the metadata of a raster.
 
     This model inherits from ``ImageSet`` and only adds an extra layer of
@@ -18,10 +17,9 @@ class Raster(TimeStampedModel, TaskEventMixin, PermissionPathMixin):
 
     """
 
-    permissions_paths = [('image_set', ImageSet)]
-
     name = models.CharField(max_length=1000, blank=True)
     description = models.TextField(null=True, blank=True)
+    extra_fields = models.JSONField(null=True, blank=True)
 
     image_set = models.OneToOneField(ImageSet, on_delete=models.CASCADE)
     ancillary_files = models.ManyToManyField(ChecksumFile, blank=True, related_name='+')
@@ -33,18 +31,16 @@ class Raster(TimeStampedModel, TaskEventMixin, PermissionPathMixin):
 
     @property
     def count(self):
+        """Get number of images."""
+        return self.image_set.count
+
+    @property
+    def number_of_bands(self):
         """Get number of bands across all images in image set."""
-        n = (
-            ImageSet.objects.filter(pk=self.image_set.pk)
-            .annotate(num_bands=Sum('images__imagemeta__number_of_bands'))
-            .first()
-            .num_bands
-        )
-        return n
+        return self.image_set.number_of_bands
 
 
-class RasterMeta(TimeStampedModel, SpatialEntry, PermissionPathMixin, DetailViewMixin):
-    permissions_paths = [('parent_raster', Raster)]
+class RasterMeta(TimeStampedModel, SpatialEntry, DetailViewMixin):
     detail_view_name = 'raster-entry-detail'
 
     parent_raster = models.OneToOneField(Raster, on_delete=models.CASCADE)
